# django-memento-framework

A set for helpers for Django web sites to enable [the Memento framework](http://timetravel.mementoweb.org/about/) for time-based access

[![Build Status](https://travis-ci.org/pastpages/django-memento-framework.png?branch=master)](https://travis-ci.org/pastpages/django-memento-framework)
[![PyPI version](https://badge.fury.io/py/django-memento-framework.png)](http://badge.fury.io/py/django-memento-framework)
[![Coverage Status](https://coveralls.io/repos/pastpages/django-memento-framework/badge.png?branch=master)](https://coveralls.io/r/pastpages/django-memento-framework?branch=master)
[![Documentation Status](https://readthedocs.org/projects/django-memento-framework/badge/?version=latest)](https://readthedocs.org/projects/django-memento-framework/?badge=latest)

* Documentation: [django-memento-framework.rtfd.org](http://django-memento-framework.rtfd.org)
* Issues: [github.com/pastpages/django-memento-framework/issues](https://github.com/pastpages/django-memento-framework/issues)
* Packaging: [pypi.python.org/pypi/django-memento-framework](https://pypi.python.org/pypi/django-memento-framework)
* Testing: [travis-ci.org/pastpages/django-memento-framework](https://travis-ci.org/pastpages/django-memento-framework)
* Coverage: [coveralls.io/r/pastpages/django-memento-framework](https://coveralls.io/r/pastpages/django-memento-framework)